@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2010 Yuichiro Moriguchi
+ * Copyright 2009-2013 Yuichiro Moriguchi
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,17 +16,19 @@
 package net.morilib.awk.stat;
 
 /**
- *
+ * 分布関数に関するユーティリティメソッドです。
+ * 
  *
  * @author MORIGUCHI, Yuichiro 2012/02/18
  */
-public class DistributionUtils {
+public final class DistributionUtils {
 
 	/**
+	 * 累積確率分布を調整します。
 	 * 
-	 * @param x
-	 * @param epsilon
-	 * @return
+	 * @param x 値
+	 * @param epsilon 調整する下限
+	 * @return 調整された値
 	 */
 	public static double trimCdf(double x, double epsilon) {
 		if(Math.abs(x) < epsilon) {
